@@ -8,13 +8,7 @@ APP = 'partners'
 
 
 class PartnerCreateContract(Contract):
-    code = serializers.CharField(max_length=8,
-                                 validators=(RegexValidator(regex='^[A-Z0-9]*$',
-                                                            message='invalid_format',
-                                                            code='invalid_format'
-                                                            ),),
-                                 allow_blank=True,
-                                 )
+    pass
 
 
 class PartnerUpdateContract(Contract):
